<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="40"/>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>Thanks</source>
        <translation>Poděkování</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Help us</source>
        <translation>Pomozte s vývojem</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="99"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>je to multiplatformní aplikace pro pohotové pořizování zachycených snímků pracovní plochy.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="101"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Je to nenáročná a přitom funkcemi nabitá aplikace, naprogramovaná pomocí Qt.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="33"/>
        <source>using Qt %1</source>
        <translation>používá Qt %1</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="104"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>Webové stránky – &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="107"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation>Licencováno pod &lt;a href=%1&gt;GPL v2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="111"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Autorská práva &amp;copy; 2009-2013, Artem „DOOMer“ Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="113"/>
        <source>Copyright &amp;copy; 2013-2025, LXQt team</source>
        <translation>Copyright &amp;copy; 2013-2025, tým LXQt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="120"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Pokud chcete, můžete se k nám připojit a pomoci. Pokud se vám tato aplikace líbí, toto je pozvánka.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="123"/>
        <source>What you can do?</source>
        <translation>Co můžete dělat?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>Překládat ScreenGrab do ostatních jazyků</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Make suggestions for next releases</source>
        <translation>Navrhovat změny/vylepšení do příštích vydání</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="128"/>
        <source>Report bugs and issues</source>
        <translation>Hlásit chyby a problémy</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="131"/>
        <source>Bug tracker</source>
        <translation>Evidence hlášení chyb</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source>Special thanks to:</source>
        <translation>Speciální poděkování pro:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="144"/>
        <source>for creating ScreenGrab</source>
        <translation>pro vytváření ScrenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source>for supporting wlr screencopy protocol</source>
        <translation>pro podporu wlr protokolu screencopy</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="190"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>Složka %1 neexistuje. Chcete ji vytvořit?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="191"/>
        <location filename="../src/core/ui/configwidget.cpp" line="280"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="268"/>
        <source>Select directory</source>
        <translation>Vybrat složku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="279"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>Opravdu chcete vrátit nastavení do výchozích hodnot?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="313"/>
        <source>Example: </source>
        <translation>Příklad: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="354"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>Tato klávesa je už ve ScreeGrab přiřazena něčemu jinému! Vyberte jinou.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="372"/>
        <source>This key is not supported on your system!</source>
        <translation>Tato klávesa není ve vámi používaném operačním systému podporována!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="392"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="66"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>je multiplatformní aplikace pro pohotové pořizování snímků obrazovky pracovní plochy.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="70"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Pořídit snímek celé obrazovky</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="74"/>
        <source>Take a screenshot of the active window</source>
        <translation>Pořídit snímek aktivního okna</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="78"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Pořídit snímek vybrané části obrazovky</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="82"/>
        <source>Run the application with a hidden main window</source>
        <translation>Spustit aplikaci tak, aby její hlavní okno zůstalo skryté</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="85"/>
        <source>Save screenshot and exit, without showing window</source>
        <translation>Uložit snímek obrazovky a skončit, bez zobrazení okna</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="587"/>
        <source>Saved</source>
        <translation>Uloženo</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="587"/>
        <source>Saved to </source>
        <translation>Uloženo do </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="609"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>Název uloženého souboru je zkopírován do schránky</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="615"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>Popis umístění uloženého souboru je zkopírován do schránky</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="638"/>
        <source>Copied</source>
        <translation>Zkopírováno</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="638"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>Snímek obrazovky je zkopírován do schránky</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="73"/>
        <source>Screen:</source>
        <translation>Obrazovka:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="105"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="115"/>
        <source>Type of screenshot</source>
        <translation>Typ snímku obrazovky</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="85"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="115"/>
        <source>Full screen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="116"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="86"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="117"/>
        <source>Screen area</source>
        <translation>Oblast obrazovky</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="87"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="118"/>
        <source>Last selected area</source>
        <translation>Posledně vybraná oblast</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="144"/>
        <source>Delay:</source>
        <translation>Prodleva:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Prodleva (v sekundách) před pořízením snímku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source>None</source>
        <translation>Žádná</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="163"/>
        <source> sec</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="222"/>
        <source>Zoom area around mouse</source>
        <translation>Přiblížit oblast okolo ukazatele myši</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="229"/>
        <source>No window decoration</source>
        <translation>Žádná dekorace okna</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="236"/>
        <source>Include mouse pointer</source>
        <translation>Včetně ukazatele myši</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="268"/>
        <source>toolBar</source>
        <translation>lišta nástrojů</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="44"/>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Options</source>
        <translation>Předvolby</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="367"/>
        <source>Screenshot </source>
        <translation>Snímek obrazovky </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="371"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Dvojklikem snímek otevřete ve výchozím prohlížeči obrázků</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="380"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="549"/>
        <source>Hide</source>
        <translation>Skrýt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="556"/>
        <source>Show</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="625"/>
        <source>%1 Files</source>
        <translation>%1 souborů</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="647"/>
        <source>Save As...</source>
        <translation>Uložit jako…</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="147"/>
        <source>Click and drag to draw a rectangle,
double click or press Enter
to take a screenshot,
or press Escape to cancel.</source>
        <translation>Kliknutím a tažením nakreslete obdélník,
dvojklikem nebo stisknutím Enter
pořiďte snímek obrazovky,
nebo stisknutím Esc zrušte.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="244"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>Klikněte a natáhněte obdélník,
kliknutím pravým tlačítkem
přizpůsobte hranám,
dvojklikem nebo stiskem klávesy
Enter pořiďte snímek obrazovky.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="304"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 pixelů </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Upravit v jiné aplikaci</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Upravit v…</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="536"/>
        <source>Options</source>
        <translation>Předvolby</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="35"/>
        <source>Main</source>
        <translation>Hlavní</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="40"/>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="45"/>
        <source>System tray</source>
        <translation>Oznamovací oblast panelu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="50"/>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="74"/>
        <source>Default save directory</source>
        <translation>Výchozí složka pro ukládání</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="80"/>
        <source>Path to default selection dir for saving</source>
        <translation>Popis umístění výchozí složky pro ukládání</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="93"/>
        <source>Browse filesystem</source>
        <translation>Procházet souborový systém</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="96"/>
        <source>Browse</source>
        <translation>Procházet</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="106"/>
        <source>Default file</source>
        <translation>Výchozí soubor</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="119"/>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="126"/>
        <source>Default filename</source>
        <translation>Výchozí název souboru</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="137"/>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="150"/>
        <source>Default saving image format</source>
        <translation>Výchozí formát pro ukládání obrázků</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="169"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Při ukládání zkopírovat název souboru do schránky</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="183"/>
        <source>Do not copy</source>
        <translation>Nekopírovat</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="188"/>
        <source>Copy file name only</source>
        <translation>Zkopírovat pouze název souboru</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="193"/>
        <source>Copy full file path</source>
        <translation>Zkopírovat úplný popis umístění souboru</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="203"/>
        <source>Image quality</source>
        <translation>Kvalita obrazu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="209"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Kvalita obrazu (1 – malý soubor, 100 – vysoká kvalita)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="274"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Vkládání aktuálního data a času do názvu uloženého souboru</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="277"/>
        <source>Insert current date and time in file name</source>
        <translation>Do názvu souboru vložit aktuální datum a čas</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="286"/>
        <source>Template: </source>
        <translation>Šablona: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="311"/>
        <source>Example: </source>
        <translation>Příklad: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="321"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Po zachycení snímky obrazovky hned automaticky ukládat</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="324"/>
        <source>Autosave screenshot</source>
        <translation>Snímek obrazovky automaticky uložit</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="336"/>
        <source>Save first screenshot</source>
        <translation>Uložit první snímek obrazovky</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="345"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Umožnit mít ScreenGrab spuštěné vícekrát vedle sebe</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="348"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Umožnit vícenásobné spuštění ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="355"/>
        <source>Open in external viewer on double click</source>
        <translation>Při dvojkliku otevřít v externím prohlížeči</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="358"/>
        <source>Enable external viewer</source>
        <translation>Používat externí prohlížeč</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="365"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>Pokud toto není zaškrtnuto, oblast výběru
se může zvětšit aby obsáhla vnější hrany</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="369"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>Kliknutím pravým tlačítkem uvnitř oblasti výběru přizpůsobíte hranám</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="376"/>
        <source>With multiple screens</source>
        <translation>S vícero obrazovkami</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="379"/>
        <source>Remember last selected screen in next session</source>
        <translation>Zapamatovat si naposledy vybranou obrazovku pro příští relaci</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="386"/>
        <source>Notify on saving and copying</source>
        <translation>Upozornit při ukládání a kopírování</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="395"/>
        <source>Duration:</source>
        <translation>Délka trvání:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="462"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>Zobrazovat ScreenGrab v oznamovací oblasti</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="402"/>
        <source> sec</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="469"/>
        <source>Minimize to tray on click close button</source>
        <translation>Při kliknutí na tlačítko zavření minimalizovat do oznamovací oblasti</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="472"/>
        <source>Minimize to tray when closing</source>
        <translation>Při zavření minimalizovat do oznamovací oblasti panelu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="511"/>
        <source>Action</source>
        <translation>Akce</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="516"/>
        <source>Shortcut</source>
        <translation>Klávesová zkratka</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="521"/>
        <source>New screen</source>
        <translation>Nová obrazovka</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="526"/>
        <source>Save screen</source>
        <translation>Uložit obrazovku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="531"/>
        <source>Copy screen</source>
        <translation>Zkopírovat obrazovku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="541"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="551"/>
        <source>Selected shortcut:</source>
        <translation>Označená klávesová zkratka:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="558"/>
        <source>Not defined</source>
        <translation>Neurčeno</translation>
    </message>
</context>
</TS>
